@@ -58,6 +58,8 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
+#include "libgnomeui-access.h"
+
 struct _GnomePixmapEntryPrivate {
 	GtkWidget *preview;
 	GtkWidget *preview_sw;
@@ -199,6 +201,10 @@ refresh_preview(GnomePixmapEntry *pentry)
         } else {
 		gtk_widget_destroy(pentry->_priv->preview->parent);
 		pentry->_priv->preview = gtk_image_new_from_pixbuf (pixbuf);
+		_add_atk_name_desc (pentry->_priv->preview,
+				    _("Image Preview"),
+				    _("A preview of the image currently specified"));
+
 		gtk_widget_show(pentry->_priv->preview);
 		gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(pentry->_priv->preview_sw),
 						      pentry->_priv->preview);
@@ -640,8 +646,6 @@ gnome_pixmap_entry_preview_widget(GnomePixmapEntry *pentry)
  * Description: Sets the default path for the file entry. The new
  * subdirectory should be specified relative to the default GNOME
  * pixmap directory.
- *
- * Returns:
  **/
 void
 gnome_pixmap_entry_set_pixmap_subdir(GnomePixmapEntry *pentry,
@@ -672,8 +676,6 @@ gnome_pixmap_entry_set_pixmap_subdir(GnomePixmapEntry *pentry,
  * the entry.  If the preview is on, we also load the files and check
  * for them being real images.  If it is off, we don't check files
  * to be real image files.
- *
- * Returns:
  **/
 void
 gnome_pixmap_entry_set_preview (GnomePixmapEntry *pentry, gboolean do_preview)
@@ -711,8 +713,6 @@ gnome_pixmap_entry_set_preview (GnomePixmapEntry *pentry, gboolean do_preview)
  *
  * Description: Sets the minimum size of the preview frame in pixels.
  * This works only if the preview is enabled.
- *
- * Returns:
  **/
 void
 gnome_pixmap_entry_set_preview_size(GnomePixmapEntry *pentry,
